@@ -447,6 +447,11 @@ class VirtualService(HttpClient, KempBaseObjectModel):
         self.schedule = service.get('Schedule', None)
         self.nickname = service.get('NickName', None)
         self.altaddress = service.get('AltAddress', None)
+        self.transparent = service.get('Transparent', None)
+        self.useforsnat = service.get('UseforSnat', None)
+        self.persist = service.get('Persist', None)
+        self.persisttimeout = service.get('PersistTimeout', None)
+        self.cookie = service.get('Cookie', None)
 
     def create_real_server(self, ip, port=80):
         """RealServer factory with pre-configured LoadMaster connection."""
